============
Installation
============

At the command line::

    $ easy_install quickbooks-py

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv quickbooks-py
    $ pip install quickbooks-py
